@@ -11,8 +11,10 @@ class Migration(migrations.Migration):
     ]
 
     operations = [
-        migrations.AlterUniqueTogether(
-            name='tagging',
-            unique_together=set([('value', 'episode', 'user')]),
+        migrations.DeleteModel(
+            name='CommunityNurse',
+        ),
+        migrations.DeleteModel(
+            name='GP',
         ),
     ]
