@@ -60,10 +60,6 @@ angular.module('opal.services')
                 return this.demographics[0].first_name + ' ' + this.demographics[0].surname;
             },
 
-            getNumberOfItems: function(columnName) {
-                return this[columnName].length;
-            },
-
             // Getter function to return active episode tags.
             // Default implementation just hits tagging
             getTags: function(){
@@ -239,63 +235,8 @@ recently changed it - refresh the page and try again');
                 return deferred.promise;
             },
 
-
-            //
-            // Predicate to determine whether this episode is discharged or not
-            //
-            isDischarged: function(){
-                return this.location[0].category == 'Discharged' ||
-                    (this.end && moment(this.end).isBefore(moment()));
-            }
         }; // Closes prototype
 
-
-        //
-        // takes two arguments, the hospital number and a hash of callbacks.
-        //
-        // There are three cases for which we proceed:
-        //
-        // 1. A new patient
-        // 2. An existing patient
-        // 3. Failure
-        //
-        // These should be expressed as { newPatient: ..., newForPatient: ..., error: ... }
-        //
-        Episode.findByHospitalNumber = function(number, callbacks){
-            var deferred = $q.defer();
-            var result = {
-                patients: [],
-                hospitalNumber: number
-            };
-            // record loader is used by the field translater to
-            // cast the results fields
-            deferred.promise.then(function(result){
-                if(!result.patients.length){
-                    callbacks.newPatient(result);
-                }else if(result.patients.length == 1){
-                    var patient = FieldTranslator.patientToJs(result.patients[0]);
-                    callbacks.newForPatient(patient)
-                }else{
-                    callbacks.error();
-                }
-            });
-
-            if(number){
-                // The user entered a hospital number
-                $http.get('/search/patient/?hospital_number=' + encodeURIComponent(number))
-                    .success(function(response) {
-                        // We have retrieved patient records matching the hospital number
-                        result.patients = response;
-                        // cast the patient fields
-                        deferred.resolve(result);
-
-                    });
-            }else{
-                deferred.resolve(result);
-            }
-        }
-
-
         return Episode
 
     });
