@@ -5,7 +5,7 @@ import os
 import copy
 
 from django.contrib.auth.models import AnonymousUser
-from mock import patch, MagicMock
+from unittest.mock import patch, MagicMock
 
 from opal.core.test import OpalTestCase
 
